/*************************************************************************
 * Copyright (C) 1995-2019, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifdef __CLING__

#pragma link off all globals;
#pragma link off all classes;
#pragma link off all functions;

#pragma link C++ class ROOT::RBrowserRequest+;
#pragma link C++ class ROOT::RBrowserReply+;

#pragma link C++ class ROOT::RBrowserData+;

#pragma link C++ class ROOT::RBrowser+;
#pragma link C++ class ROOT::RFileDialog+;

#pragma link C++ class ROOT::RWebBrowserImp+;

#endif
